@@ -1,11 +1,10 @@
-
-__all__ = ['DB']
-
 from sqlalchemy.ext.declarative import declarative_base
+from skyext.db.postgre_db import Postgre
 
-from skyext.db.postgre_db import PG
+__all__ = ('DataBase',)
 
-class DB(object):
+
+class DataBase(object):
     def __int__(self):
         self._url = None
         self._protocol = None
@@ -19,7 +18,7 @@ class DB(object):
         if not hasattr(config, "SQLALCHEMY_DATABASE_URI"):
             return
 
-        self._url = config.CACHE_URL
+        self._url = config.SQLALCHEMY_DATABASE_URI
         url_protocol = str(self._url).lower().split(":")
         self._protocol = url_protocol[0]
 
@@ -34,8 +33,6 @@ class DB(object):
         if not self._model:
             if self._db:
                 self._model = self._db.model
-            else:
-                self._model = declarative_base()
 
         return self._model
 
@@ -44,7 +41,6 @@ class DB(object):
         return self._db.session
 
 
-
 class DBFactory(object):
     def __init__(self):
         pass
@@ -53,7 +49,7 @@ class DBFactory(object):
     def create_pg(cls, url=None, **kwargs):
         if not url:
             return
-        return PG().init(url=url, **kwargs)
+        return Postgre().init(url=url, **kwargs)
 
     @classmethod
     def create_mysql(cls, config):
