@@ -3,7 +3,7 @@ from sqlalchemy.orm import sessionmaker, scoped_session
 from sqlalchemy.ext.declarative import declarative_base
 
 
-class PG(object):
+class Postgre(object):
     def __init__(self):
         self._model = None
         self._session_factory = None
@@ -16,6 +16,8 @@ class PG(object):
             self.engine = create_engine(url)
 
         self._session_factory = scoped_session(sessionmaker(bind=self.engine))
+        if not self._model:
+            self._model = declarative_base()
         self._model.metadata.create_all(self.engine)
         self._session = self._session_factory()
 
